geowatch.tasks.cold.export\_change\_map module
==============================================

.. automodule:: geowatch.tasks.cold.export_change_map
   :members:
   :undoc-members:
   :show-inheritance:
